/*

  This file is a part of GRALESHELL, a program to facilitate the simulation
  and inversion of gravitational lenses, based on the GRALE library.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#include "cmdunits.h"
#include "cmdcosmology.h"
#include "cmdcalc.h"
#include "cmdgrid.h"
#include "cmdimageplane.h"
#include "cmdimagesdata.h"
#include "cmdinvert.h"
#include "cmdlenses.h"
#include "cmdlensplane.h"
#include "cmdsources.h"
#include <shellp/cmdeval.h>
#include <shellp/cmdexit.h>
#include <shellp/cmdecho.h>
#include <shellp/cmdhelp.h>
#include <shellp/cmdexec.h>
#include <shellp/cmdimport.h>
#include <shellp/cmdexport.h>
#include <shellp/cmddefine.h>
#include <list>

#include "debugnew.h"

std::list<shellp::ShellCommand *> registeredCommands;

void RegisterCommands()
{
	registeredCommands.push_back(new shellp::CmdExit("exit"));
	registeredCommands.push_back(new shellp::CmdExit("quit"));
	registeredCommands.push_back(new shellp::CmdHelp("help"));
	registeredCommands.push_back(new shellp::CmdExecute("exec"));
	registeredCommands.push_back(new shellp::CmdEcho("echo"));
	registeredCommands.push_back(new shellp::CmdImport("import"));
	registeredCommands.push_back(new shellp::CmdExport("export"));
	registeredCommands.push_back(new shellp::CmdDefine("pre/def"));
	registeredCommands.push_back(new shellp::CmdListDefines("pre/list"));
	registeredCommands.push_back(new shellp::CmdEval("math/def", true, true));
	registeredCommands.push_back(new shellp::CmdEval("math/calc", true, false));
	registeredCommands.push_back(new shellp::CmdEvalList("math/list"));
	registeredCommands.push_back(new shellp::CmdEvalClearVar("math/clearvar"));
	registeredCommands.push_back(new CmdCalcCriticalDensity("math/critdens"));
	registeredCommands.push_back(new CmdLensPointmass("lens/new/pointmass"));
	registeredCommands.push_back(new CmdLensPlummer("lens/new/plummer"));
	registeredCommands.push_back(new CmdLensGauss("lens/new/gaussian"));
	registeredCommands.push_back(new CmdLensMultiplePlummers("lens/new/mplummers"));
	registeredCommands.push_back(new CmdLensNSIE("lens/new/nsie"));
	registeredCommands.push_back(new CmdLensNSIS("lens/new/nsis"));
	registeredCommands.push_back(new CmdLensSIE("lens/new/sie"));
	registeredCommands.push_back(new CmdLensSIS("lens/new/sis"));
	registeredCommands.push_back(new CmdLensSquare("lens/new/square"));
	registeredCommands.push_back(new CmdLensMultipleSquares("lens/new/msquares"));
	registeredCommands.push_back(new CmdLensMultipleSquaresFits("lens/new/msquaresfits"));
	registeredCommands.push_back(new CmdLensMultipleGaussians("lens/new/mgaussians"));
	registeredCommands.push_back(new CmdLensMassSheet("lens/new/sheet"));
	registeredCommands.push_back(new CmdLensMassDisk("lens/new/disk"));
	registeredCommands.push_back(new CmdLensAverage("lens/new/average"));
	registeredCommands.push_back(new CmdLensMassSheetDegeneracy("lens/new/sheetdegen"));
	registeredCommands.push_back(new CmdLensMassDiskDegeneracy("lens/new/diskdegen"));
	registeredCommands.push_back(new CmdLensComposite("lens/new/composite"));
	registeredCommands.push_back(new CmdLensScaleDegeneracy("lens/new/scaledegen"));
	registeredCommands.push_back(new CmdLensMultipleWendland("lens/new/mwendlands"));
	registeredCommands.push_back(new CmdLensTimeDelayAdjust("lens/new/timedelay"));
	registeredCommands.push_back(new CmdLensMagnificationAdjust("lens/new/magadjust"));
	registeredCommands.push_back(new CmdLensNFW("lens/new/nfw"));
	registeredCommands.push_back(new CmdLensEllipticNFW("lens/new/ellnfw"));
	registeredCommands.push_back(new CmdLensSersic("lens/new/sersic"));
	registeredCommands.push_back(new CmdLensEllipticSersic("lens/new/ellsersic"));
	registeredCommands.push_back(new CmdLensTestLens("lens/new/test"));
	registeredCommands.push_back(new CmdLensGetImagePlane("lens/get/imgplane"));
	registeredCommands.push_back(new CmdLensGetLensPlane("lens/get/lensplane"));
	registeredCommands.push_back(new CmdLensGetLensPlaneGrid("lens/get/lpgrid"));
	registeredCommands.push_back(new CmdLensLoad("lens/load"));
	registeredCommands.push_back(new CmdLensSave("lens/save"));
	registeredCommands.push_back(new CmdLensPlotGnuplot("lens/plot/gnuplot"));
	registeredCommands.push_back(new CmdLensPlotFITS("lens/plot/fits"));
	registeredCommands.push_back(new CmdLensPlotProfile("lens/profile"));
	registeredCommands.push_back(new CmdSourcePlane("srcplane/new"));
	registeredCommands.push_back(new CmdSourcePlaneImagesData("srcplane/new/imgdata"));
	registeredCommands.push_back(new CmdSourcePlaneImagesDataPointSource("srcplane/new/pointimgdata"));
	registeredCommands.push_back(new CmdSourcePlaneLoad("srcplane/load"));
	registeredCommands.push_back(new CmdSourcePlaneSave("srcplane/save"));
	registeredCommands.push_back(new CmdSourcesAddCircular("sources/add/circle"));
	registeredCommands.push_back(new CmdSourcesAddElliptical("sources/add/ellipse"));
	registeredCommands.push_back(new CmdSourcesAddFITS("sources/add/fits"));
	registeredCommands.push_back(new CmdSourcesAddPolygon("sources/add/polygon"));
	registeredCommands.push_back(new CmdSourcesAddPoint("sources/add/point"));
	registeredCommands.push_back(new CmdSourcesDelete("sources/delete"));
	registeredCommands.push_back(new CmdSourcesClear("sources/clearall"));
	registeredCommands.push_back(new CmdSourcesMove("sources/move"));
	registeredCommands.push_back(new CmdSourcesRotate("sources/rotate"));
	registeredCommands.push_back(new CmdLensPlaneLocal("lensplane/new/local"));
	registeredCommands.push_back(new CmdLensPlaneRemote("lensplane/new/remote"));
	registeredCommands.push_back(new CmdLensPlaneLoad("lensplane/load"));
	registeredCommands.push_back(new CmdLensPlaneSave("lensplane/save"));
	registeredCommands.push_back(new CmdLensPlaneScale("lensplane/scale"));
	registeredCommands.push_back(new CmdLensPlanePlotGnuplot("lensplane/plotdens/gnuplot"));
	registeredCommands.push_back(new CmdLensPlanePlotFITS("lensplane/plotdens/fits"));
	registeredCommands.push_back(new CmdImagePlaneLocal("imgplane/new/local"));
	registeredCommands.push_back(new CmdImagePlaneRemote("imgplane/new/remote"));
	registeredCommands.push_back(new CmdImagePlaneLensPlane("imgplane/new/lensplane"));
	registeredCommands.push_back(new CmdImagePlanePlotGnuplot("imgplane/plot/gnuplot"));
	registeredCommands.push_back(new CmdImagePlanePlotPNG("imgplane/plot/png"));
	registeredCommands.push_back(new CmdImagePlanePlotAscii("imgplane/plot/ascii"));
	registeredCommands.push_back(new CmdImagePlanePlotFITS("imgplane/plot/fits"));
	registeredCommands.push_back(new CmdImagePlanePlotMagnification("imgplane/plotmag"));
	registeredCommands.push_back(new CmdImagePlaneTraceBeta("imgplane/trace/beta"));
	registeredCommands.push_back(new CmdImagePlaneTraceTheta("imgplane/trace/theta"));
	registeredCommands.push_back(new CmdImagePlaneTraceImgData("imgplane/trace/imgdata"));
	registeredCommands.push_back(new CmdImagePlaneTimeDelay("imgplane/timedelay"));
	registeredCommands.push_back(new CmdImagesDataLoad("imgdata/load"));
	registeredCommands.push_back(new CmdImagesDataSave("imgdata/save"));
	registeredCommands.push_back(new CmdImagesDataTriangulationCreate("imgdata/triang/new"));
	registeredCommands.push_back(new CmdImagesDataTriangulationClear("imgdata/triang/clear"));
	registeredCommands.push_back(new CmdImagesDataNewRegular("imgdata/new/reg"));
	registeredCommands.push_back(new CmdImagesDataAddRegular("imgdata/add/reg"));
	registeredCommands.push_back(new CmdImagesDataNewPoints("imgdata/new/points"));
	registeredCommands.push_back(new CmdImagesDataNew("imgdata/new"));
	registeredCommands.push_back(new CmdImagesDataAddPoints("imgdata/add/points"));
	registeredCommands.push_back(new CmdImagesDataAddShearInfo("imgdata/add/shear"));
	registeredCommands.push_back(new CmdImagesDataSubtractPosition("imgdata/sub/pos"));
	registeredCommands.push_back(new CmdImagesDataSubtractIntensity("imgdata/sub/intens"));
	registeredCommands.push_back(new CmdImagesDataSelect("imgdata/select"));
	registeredCommands.push_back(new CmdImagesDataSourceImage("imgdata/srcimage"));
	registeredCommands.push_back(new CmdImagesDataImportPNG("imgdata/import/png"));
	registeredCommands.push_back(new CmdImagesDataImportFITS("imgdata/import/fits"));
	registeredCommands.push_back(new CmdImagesDataImportFITSAuto("imgdata/import/fitsauto"));
	registeredCommands.push_back(new CmdImagesDataImportFITSWCS("imgdata/import/fitswcs"));
	registeredCommands.push_back(new CmdImagesDataListAdd("imgdata/list/add"));
	registeredCommands.push_back(new CmdImagesDataListClear("imgdata/list/clear"));
	registeredCommands.push_back(new CmdImagesDataBackProjectAll("imgdata/backproj/all"));
	registeredCommands.push_back(new CmdImagesDataFitness("imgdata/fitness"));
	registeredCommands.push_back(new CmdImagesDataNonDominatedSet("imgdata/nds"));
	registeredCommands.push_back(new CmdInvertGridLocal("invert/grid/local"));
	registeredCommands.push_back(new CmdInvertGridRemote("invert/grid/remote"));
	registeredCommands.push_back(new CmdInvertGridNewLocal("invert/gridnew/local"));
	registeredCommands.push_back(new CmdInvertGridNewRemote("invert/gridnew/remote"));
	registeredCommands.push_back(new CmdInvertTreeLocal("invert/tree/local"));
	registeredCommands.push_back(new CmdInvertTreeRemote("invert/tree/remote"));
	registeredCommands.push_back(new CmdInvertAreaLocal("invert/area/local"));
	registeredCommands.push_back(new CmdInvertAreaRemote("invert/area/remote"));
	registeredCommands.push_back(new CmdInvertGAParamsShow("invert/gaparams/show"));
	registeredCommands.push_back(new CmdInvertGAParamsSet("invert/gaparams/set"));
	registeredCommands.push_back(new CmdUnitMassShow("unit/mass/show"));
	registeredCommands.push_back(new CmdUnitMassSet("unit/mass/set"));
	registeredCommands.push_back(new CmdUnitAngularShow("unit/angular/show"));
	registeredCommands.push_back(new CmdUnitAngularSet("unit/angular/set"));
	registeredCommands.push_back(new CmdUnitDistanceShow("unit/distance/show"));
	registeredCommands.push_back(new CmdUnitDistanceSet("unit/distance/set"));
	registeredCommands.push_back(new CmdCosmologyShow("cosm/show"));
	registeredCommands.push_back(new CmdCosmologySet("cosm/set"));
	registeredCommands.push_back(new CmdGridNewUniform("grid/new/uniform"));
	registeredCommands.push_back(new CmdGridNewLens("grid/new/lens"));
	registeredCommands.push_back(new CmdGridPlot("grid/plot"));
}

void UnregisterCommands()
{
	while (!registeredCommands.empty())
	{
		delete *(registeredCommands.begin());
		registeredCommands.pop_front();
	}
}

